def get_versions():
    return versions[0]["number"]


versions = [
    {
        "number": "0.1.6",
        "features": [
            "1. change genblasta timeout to 5min",
        ],
    },
    {
        "number": "0.1.5",
        "features": [
            "1. debug",
        ],
    },
    {
        "number": "0.1.4",
        "features": [
            "1. Remove the time limit of genewise",
        ],
    },
    {
        "number": "0.1.3",
        "features": [
            "1. debug",
        ],
    },
    {
        "number": "0.1.2",
        "features": [
            "1. debug",
            "2. modify log file",
        ],
    },
    {
        "number": "0.1.1",
        "features": [
            "1. debug",
        ],
    },
    {
        "number": "0.1.0",
        "features": [
            "1. Separate WPGmapper from ToolBiox and rename as HugeP2G",
        ],
    },
]
